.. SPDX-FileCopyrightText: Copyright © 2025 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _mednet.databases.classify.angioreport:

=============
 AngioReport
=============

* DataModule and support code: :py:mod:`.data.classify.angioreport`
* Splits:

  .. list-table::
     :align: left

     * - Config. key
       - Module
     * - ``angioreport-hyperftype``
       - :py:mod:`.config.classify.data.angioreport.hyperftype`
     * - ``angioreport-cnv``
       - :py:mod:`.config.classify.data.angioreport.cnv`
     * - ``angioreport-cnv-icga``
       - :py:mod:`.config.classify.data.angioreport.cnv_icga`
     * - ``angioreport-impression``
       - :py:mod:`.config.classify.data.angioreport.impression`
